-- Options.lua : Options config

if select(6, GetAddOnInfo("Guilder_" .. (debugstack():match("[o%.][d%.][u%.]les\\(.-)\\") or ""))) ~= "MISSING" then return end

local _G = _G
local Guilder = _G.Guilder
local Guilder_Monitor = Guilder:GetModule("Monitor")
local L = LibStub("AceLocale-3.0"):GetLocale("Guilder")

Guilder_Monitor:SetGlobalOptionsFunction(function(self)
	return "control", {
		type = "group",
		name = L["Monitor Settings"],
		desc = "",
		inline = true,
		args = {
			desc = {
				type = "description",
				name = L["Monitor shows what flask/elixirs and food you have taken. It can also send a request to other players in your group who have this addon installed and report what they have."],
				order = 0
			},
			CheckSelf = {
				type = "execute",
				name = L["Check Player"],
				desc = L["Click here to check if the player has missing consumables"],
				order = 1,
				func = function() self:CheckConsumables() end
			},
			CheckRaid = {
				type = "execute",
				name = L["Check Group"],
				desc = L["Click here to check if the group has missing consumables"],
				disabled = true,
				order = 3,
				func = function() self:CheckGroupConsumables() end
			}
		}
	}, "settings", {
		type = "group",
		name = L["Settings"],
		desc = "",
		inline = true,
		args = {
			h1 = {
				type = "header",
				name = L["Minimum Acceptable"],
				desc = "",
				order = 10
			},
			MinFlask = {
				type = "select",
				name = L["Flask"],
				desc = L["Minimum Flask level to accept"],
				order = 11,
				style = "radio",
				values = { [0] = L["Don't check"], [1] = L["The Burning Crusade"], [2] = L["Good The Burning Crusade"], [3] = L["Wraith of the Lich King"] },
				get = function() return self.db.profile.minFlask end,
				set = function(info, v) self.db.profile.minFlask = v end
			},
			MinElixir = {
				type = "select",
				name = L["Elixir"],
				desc = L["Minimum Elixir level to accept"],
				order = 12,
				style = "radio",
				values = { [0] = L["Don't Check"], [1] = L["The Burning Crusade"], [2] = L["Good The Burning Crusade"], [3] = L["Wraith of the Lich King"] },
				get = function() return self.db.profile.minElixir end,
				set = function(info, v) self.db.profile.minElixir = v end
			},
			MinFood = {
				type = "select",
				name = L["Food"].."*",
				desc = L["Minimum Food level to accept"],
				order = 13,
				style = "radio",
				values = { [0] = L["Don't Check"], [1] = L["Well Fed"] },
				get = function() return self.db.profile.minFood end,
				set = function(info, v) self.db.profile.minFood = v end
			},
			h2 = {
				type = "header",
				name = L["What to Report"],
				desc = "",
				order = 20
			},
			Flasks = {
				type = "toggle",
				name = L["Flasks"],
				desc = L["Report missing flasks?"],
				order = 21,
				get = function() return self.db.profile.checkFlasks end,
				set = function(info, v) self.db.profile.checkFlasks = v end
			},
			Elixirs = {
				type = "toggle",
				name = L["Elixirs"],
				desc = L["Report missing elixirs?"],
				order = 22,
				get = function() return self.db.profile.checkElixirs end,
				set = function(info, v) self.db.profile.checkElixirs = v end
			},
			Food = {
				type = "toggle",
				name = L["Food"].."*",
				desc = L["Report missing food?"],
				order = 23,
				get = function() return self.db.profile.checkFood end,
				set = function(info, v) self.db.profile.checkFood = v end
			},
			Expiring = {
				type = "toggle",
				name = L["Expiring Consumables"],
				desc = L["Report expiring consumables?"],
				order = 24,
				get = function() return self.db.profile.checkExpiring end,
				set = function(info, v) self.db.profile.checkExpiring = v end
			},
			Dead = {
				type = "toggle",
				name = L["Dead Players"],
				desc = L["Report which group members are dead?"],
				order = 25,
				get = function() return self.db.profile.checkDead end,
				set = function(info, v) self.db.profile.checkDead = v end
			},
			Offline = {
				type = "toggle",
				name = L["Offline Players"],
				desc = L["Report which group members are offline?"],
				order = 26,
				get = function() return self.db.profile.checkOffline end,
				set = function(info, v) self.db.profile.checkOffline = v end
			},
			h3 = {
				type = "header",
				name = L["When to Report"],
				desc = "",
				order = 30
			},
			OnReady = {
				type = "toggle",
				name = L["On Ready Check"],
				desc = L["Report when a ready check is issued?"],
				order = 31,
				get = function() return self.db.profile.reportOnReadyCheck end,
				set = function(info, v) self.db.profile.reportOnReadyCheck = v end
			},
			OnEnter = {
				type = "toggle",
				name = L["On Combat Start"],
				desc = L["Report at the start of combat?"],
				order = 32,
				get = function() return self.db.profile.reportOnCombatEnter end,
				set = function(info, v) self.db.profile.reportOnCombatEnter = v end
			},
			OnExit = {
				type = "toggle",
				name = L["On Combat End"],
				desc = L["Report at the end of combat?"],
				order = 33,
				get = function() return self.db.profile.reportOnCombatExit end,
				set = function(info, v) self.db.profile.reportOnCombatExit = v end
			},
			Expiry = {
				type = "range",
				name = L["Warning Time"],
				desc = L["How long before the buff expires do you want to be warned?"],
				order = 34,
				width = "full",
				get = function() return self.db.profile.expiryLimit end,
				set = function(info, v) self.db.profile.expiryLimit = v end,
				min = 1,
				max = 30,
				step = 1,
				isPercent = false
			},
			h4 = {
				type = "header",
				name = L["Please Note"],
				desc = "",
				order = 35
			},
			disclaimer = {
				type = "description",
				name = L["Food only checks for 2 food buffs at the moment. This list will be expanded in the near future."],
				order = 36
			}
		}
	}
end)
